
package ASP4::GlobalASA;

use strict;
use warnings 'all';
use base 'ASP4::HTTPHandler';
use vars __PACKAGE__->VARS;

sub Script_OnStart { }
sub Script_OnEnd { }
sub Session_OnStart { }

1;# return true:

